%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Fiandra report
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{fiandrareport}[2010/10/27 Fiandra report class]
\LoadClassWithOptions{report}
\RequirePackage{etex}
\RequirePackage{amsmath, amssymb, amscd,amsfonts}
\RequirePackage{tabularx}
\RequirePackage{fancyhdr} 
\RequirePackage{tikz,pgf,pgfkeys,pgfplots}
\usetikzlibrary{topaths,trees,positioning,arrows,decorations,decorations.footprints,decorations.shapes,patterns,shadows,shapes.geometric,shapes.arrows,shapes.multipart,shapes.symbols,chains}
\RequirePackage{graphicx}
%\RequirePackage{pstricks,pstricks-add}
\RequirePackage{listings}
\lstset{language=[LaTeX]TeX,%
        basicstyle=\footnotesize\ttfamily,
	commentstyle=\color{blue},%
	showstringspaces=false,
	numbers=left, numberstyle=\scriptsize}
\RequirePackage{colortbl}
\RequirePackage{booktabs}
\RequirePackage{upgreek,latexsym,wasysym}
\RequirePackage{circuitikz}

\providecommand{\purpleddag}{\color{purple}{\ddag}}
\providecommand{\burntorangeddag}{\color{burntorange}{\ddag}}
\providecommand{\navyblueddag}{\color{navyblue}{\ddag}}
\providecommand{\redorangeddag}{\color{redorange}{\ddag}}
\providecommand{\pinegreenddag}{\color{forestgreen}{\ddag}}
\providecommand{\maroonddag}{\color{maroon}{\ddag}}

\RequirePackage[perpage,para,symbol*]{footmisc}
\DefineFNsymbols*{cfiandra}{\purpleddag\burntorangeddag\navyblueddag\maroonddag\pinegreenddag\redorangeddag\dagger *\S\P\|%
          {**}{\dagger\dagger}{\ddagger\ddagger}}
\setfnsymbol{cfiandra}
\RequirePackage{engtlc}
% XeLaTeX support
\RequirePackage{ifxetex}%
\ifxetex
  \RequirePackage{metalogo}%
  \RequirePackage{xkeyval}%
  \RequirePackage{polyglossia}%
  \setmainlanguage{italian}%
\else
  \RequirePackage[italian]{babel}
  \RequirePackage[utf8x]{inputenc}
\fi
\RequirePackage{fiandracolors}
\RequirePackage[pdfauthor={Fiandrino Claudio},pdfpagelabels,plainpages=false,colorlinks=true,hyperindex=true]{hyperref}

\def\titolo#1{\gdef\@title{#1}}
\def\autore#1{\gdef\@author{#1}}
\def\data#1{\gdef\@date{#1}}
\def\firma#1{\gdef\@firma{#1}}
\def\colorefirma#1{\gdef\@colorefirma{#1}}
\def\colorelinks#1{\gdef\@colorelinks{#1}}
\def\noteaggiuntive#1{\gdef\@note{#1}}
\def\altezza#1{\gdef\@altezza{#1}}

\providecommand{\logopoli}{
\begin{figure}[h]
\begin{center}
\includegraphics[width=.5\linewidth, height=.5\textheight, keepaspectratio]{logopolito.eps}
\end{center}
\end{figure}
}
\providecommand{\stemmacf}{
\begin{center}
\begin{tikzpicture}
\fill[green!30!forestgreen] (0,0) rectangle (1,1) ;
\node[white,ultra thick] at (.5,.5) {\LARGE \ddag} ;
\end{tikzpicture}
\end{center}
}
\providecommand{\firmaautore}{$\mathcal{\@firma}$}
%\hypersetup{linkcolor=\@colorelinks}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Prima pagina
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\def\primapaginastemma{
\pagestyle{empty}
\advance\oddsidemargin \evensidemargin
	      \divide\oddsidemargin \tw@
	      \evensidemargin \oddsidemargin
\vspace{2.5cm}
\Huge\bf{\begin{center}\@title\end{center}}
\vspace{.05cm}
\normalfont\LARGE{\begin{center}\@note\end{center}}
\vspace{.3cm}
\normalfont\huge{\begin{center}\@author\end{center}}
\vspace{1cm}
\normalfont\large{\begin{center} \if !\@date! \empty \today \else \@date \fi \end{center}}
\vspace{\@altezza}
\stemmacf
\hfil\newpage
}

\def\primapaginalogo{
\pagestyle{empty}
\advance\oddsidemargin \evensidemargin
	      \divide\oddsidemargin \tw@
	      \evensidemargin \oddsidemargin
\logopoli
\vspace{1cm}
\Huge\bf{\begin{center}\@title\end{center}}
\vspace{.5cm}
\normalfont\LARGE{\begin{center}\@note \end{center}}
\vspace{0.5cm}
\normalfont\huge{\begin{center}\@author\end{center}}
\vspace{1cm}
\normalfont\large{\begin{center} \if !\@date! \empty \today \else \@date \fi \end{center}}
\newpage
}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Indice
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\def\indice{
\tableofcontents
}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Corpo del testo
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\def\corpotesto{
\pagestyle{fancy}
\fancyhead{}
\fancyhead[L]{\@title}
\fancyhead[R]{\color{\@colorefirma}{\firmaautore}}
}

\endinput
