%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Formulario report class
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{formulary}[2011/01/17 Formulary report class]
\LoadClassWithOptions{report}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\RequirePackage{etex}
\RequirePackage{amsmath, amssymb, amscd}
\RequirePackage{tabularx}
\RequirePackage{fancyhdr} 
\RequirePackage{tikz,pgf,pgfkeys,pgfplots}
\usetikzlibrary{topaths,trees,positioning,arrows,decorations,patterns,shadows,shapes.geometric,shapes.arrows,shapes.multipart,chains}
\RequirePackage{amsfonts}
\RequirePackage{amssymb}
\RequirePackage{graphicx}
\RequirePackage{pstricks,pstricks-add}
\RequirePackage[utf8x]{inputenc}
\RequirePackage{listings}
\lstset{language=[LaTeX]TeX,%
        basicstyle=\footnotesize\ttfamily}
\lstset{language=Matlab,%
        basicstyle=\scriptsize\ttfamily,%
        commentstyle=\color{blue},%
	showstringspaces=false,
	numbers=left, numberstyle=\scriptsize}

\RequirePackage{booktabs}
\RequirePackage{colortbl}
\RequirePackage{upgreek,latexsym,wasysym}
\RequirePackage{circuitikz}

\providecommand{\purpleddag}{\color{purple}{\ddag}}
\providecommand{\burntorangeddag}{\color{burntorange}{\ddag}}
\providecommand{\navyblueddag}{\color{navyblue}{\ddag}}
\providecommand{\redorangeddag}{\color{redorange}{\ddag}}
\providecommand{\pinegreenddag}{\color{forestgreen}{\ddag}}
\providecommand{\maroonddag}{\color{maroon}{\ddag}}

\RequirePackage[multiple,perpage,bottom,symbol*]{footmisc}
\DefineFNsymbols*{cfiandra}{\purpleddag\burntorangeddag\navyblueddag\maroonddag\pinegreenddag\redorangeddag\dagger *\S\P\|%
          {**}{\dagger\dagger}{\ddagger\ddagger}}
\setfnsymbol{cfiandra}

\RequirePackage[english]{babel}
\RequirePackage{engtlc}
\RequirePackage{fiandracolors}
\RequirePackage[pdfauthor={Fiandrino Claudio},pdfpagelabels,plainpages=false,colorlinks=true,hyperindex=true]{hyperref}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\def\ateneo#1{\gdef\@nomeateneo{#1}}
\def\corso#1{\gdef\@nomecorso{#1}}
\def\titolo#1{\gdef\@title{#1}}
\def\anno#1{\gdef\@anno{#1}}
\def\data#1{\gdef\@date{#1}}
\def\versione#1{\gdef\@versione{#1}}
\def\autore#1{\gdef\@autore{#1}}

%\def\colorelinks#1{\gdef\@colorelinks{#1}}
%\def\coloreurl#1{\gdef\@coloreurl{#1}}
%\hypersetup{linkcolor=\@colorelinks}
%\hypersetup{urlcolor=\@coloreurl}

\def\logo#1{\edef\@logo{\noexpand\includegraphics[keepaspectratio,width=3cm]{#1}}}

\def\frontespizio{
\pagestyle{empty}
\advance\oddsidemargin \evensidemargin
	      \divide\oddsidemargin \tw@
	      \evensidemargin \oddsidemargin
{\vspace*{-3\topskip}\centering \expandafter{\LARGE \textsc{\@nomeateneo}}\par}\vfill
{\centering \@logo\par}\vfill
{\centering \bf\huge \@nomecorso\par}\vfill
{\centering \bf\LARGE \@title\par}\vfill
{\centering \Large Academic Year \@anno\\
}\vfill
\vfill\par\newpage
}

\def\frontespizioaut{
\pagestyle{empty}
\advance\oddsidemargin \evensidemargin
	      \divide\oddsidemargin \tw@
	      \evensidemargin \oddsidemargin
{\vspace*{-3\topskip}\centering \expandafter{\Large \textsc{\@nomeateneo}}\par}\vfill
{\centering \@logo\par}\vfill
{\centering \bf\huge \@nomecorso\par}\vfill
{\centering \bf\LARGE \@title\par}\vfill
{\centering \LARGE \@autore\par}\vfill
{\centering \large Academic Year \@anno\\
}\vfill
\vfill\par\newpage
}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Corpo del testo
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\def\corpotesto{
\pagestyle{fancy}
\fancyhead{}
\fancyhead[R]{\@title \, \small{\textit{ver.}}\:\footnotesize{\@versione}}
\fancyhead[L]{\textsc{\@nomeateneo}}
}

\endinput
