%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Monografia class
%
% Copyright 2010 Claudio Fiandrino 
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{monografia}[2010/07/02 Monografia class]
\LoadClassWithOptions{report}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\RequirePackage{etex}
\RequirePackage{amsmath, amssymb, amscd}
\RequirePackage{tabularx}
\RequirePackage{fancyhdr} 
\RequirePackage{tikz,pgf,pgfkeys,pgfplots}
\usetikzlibrary{topaths,trees,positioning,arrows,decorations,patterns,shadows,shapes.geometric,shapes.arrows,shapes.multipart,chains}
\RequirePackage{float}
\floatplacement{figure}{H}
\RequirePackage{amsfonts}
\RequirePackage{amssymb}
\RequirePackage{graphicx}
\RequirePackage[utf8x]{inputenc}  %%%% per linux
%% \RequirePackage{ansinew}       %%%% per windows
\RequirePackage{listings}
\lstset{backgroundcolor=\color{royalblue!5}}
\lstset{frameround=fttt}
\lstset{language=[LaTeX]TeX,%
        basicstyle=\footnotesize\ttfamily,
	commentstyle=\color{blue},%
	showstringspaces=false,
	numbers=left, numberstyle=\scriptsize}
\lstset{language=php,%
        basicstyle=\scriptsize\ttfamily,%
        commentstyle=\color{blue},%
	keywordstyle=\color{maroon}\bf,%
	showstringspaces=false,
	numbers=left, numberstyle=\scriptsize}
\lstset{language=SQL,%
        basicstyle=\scriptsize\ttfamily,%
        commentstyle=\color{blue},%
	keywordstyle=\color{maroon}\bf,%
	showstringspaces=false,
	numbers=left, numberstyle=\scriptsize}
\lstdefinelanguage{javascript}{keywords=[10]{var,function,for,if,else,length,new,while,name,this}, morecomment=[l]{//},morecomment=[s]{/*}{*/}}
\lstset{language=javascript,%
        basicstyle=\scriptsize\ttfamily,%
        commentstyle=\color{blue},%
	keywordstyle=\color{maroon}\bf,%
	showstringspaces=false,
	numbers=left, numberstyle=\scriptsize}
\RequirePackage{booktabs}
\RequirePackage{colortbl}
\RequirePackage{upgreek,latexsym,wasysym}
\RequirePackage[italian]{babel}
\RequirePackage{engtlc}
\RequirePackage{fiandracolors}
\RequirePackage[pdfauthor={Maria Gabriella Antona - Fiandrino Claudio},pdfpagelabels,plainpages=false,colorlinks=true,hyperindex=true]{hyperref}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\def\ateneo#1{\gdef\@nomeateneo{#1}}
\def\corso#1{\gdef\@nomecorso{#1}}
\def\titolo#1{\gdef\@title{#1}}

\def\professore#1{\gdef\@professore{#1}}

\def\nome#1{\gdef\@nome{#1}}
\def\nomea#1{\gdef\@nomea{#1}}

\def\cognome#1{\gdef\@cognome{#1}}
\def\cognomea#1{\gdef\@cognomea{#1}}

\def\data#1{\gdef\@date{#1}}
\def\colorelinks#1{\gdef\@colorelinks{#1}}
\hypersetup{linkcolor=\@colorelinks}
\def\coloreurl#1{\gdef\@coloreurl{#1}}
\hypersetup{urlcolor=\@coloreurl}

\def\logo#1{\edef\@logo{\noexpand\includegraphics[keepaspectratio,width=3.5cm]{#1}}}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Frontespizio
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


\def\frontespizio{
\pagestyle{empty}
\advance\oddsidemargin \evensidemargin
	      \divide\oddsidemargin \tw@
	      \evensidemargin \oddsidemargin
{\vspace*{-3\topskip}\centering \expandafter{\Large \@nomeateneo}\par}\vfill
{\centering \@logo\par}\vfill
{\centering \bf\huge \@nomecorso\par}\vfill
{\centering \bf\LARGE \@title\par}\vfill
{\centering \LARGE
\@cognome\; \@nome \\
\@cognomea\; \@nomea \\
}\vfill
{\centering \Large Professore: \@professore\par}\vfill
{\centering \large \if !\@date! \empty \today \else \@date \fi \par}\vfill
\vfill\par\newpage
}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Corpo del testo
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\def\corpotesto{
\pagestyle{fancy}
\def\chaptermark##1{\markright{##1}}
\def\sectionmark##1{}
\fancyhead{}
\fancyhead[C]{\it Monografia \, - \, \rightmark}
}

\def\corpotestoreg{
\pagestyle{fancy}
\fancyhead{}
\fancyhead[C]{\it \@title}
}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Indice
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\def\indice{
\tableofcontents
}

\endinput
