%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Scientific Fiandra report
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{engscientrep}[2011/05/21 Scientific english report class]
\LoadClassWithOptions{article}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\RequirePackage{etex}
\RequirePackage{amsmath, amssymb, amscd}
\RequirePackage{tabularx}
\RequirePackage{fancyhdr} 
\RequirePackage{tikz,pgf,pgfkeys,pgfplots}
\usetikzlibrary{topaths,trees,positioning,arrows,decorations,patterns,shadows,shapes.geometric,shapes.arrows,shapes.multipart,chains}
\RequirePackage{amsfonts}
\RequirePackage{amssymb}
\RequirePackage{graphicx}
%\RequirePackage{pstricks,pstricks-add}
\RequirePackage[utf8x]{inputenc}
\RequirePackage{listings}
\lstset{backgroundcolor=\color{goldenrod!15}}
\lstset{frame=trBL}
\lstset{language=SQL,%
        basicstyle=\footnotesize\ttfamily,%
        commentstyle=\color{blue},%
        morekeywords={if,begin,declare,new},%
	keywordstyle=\color{redorange}\small,%
	showstringspaces=false}
\RequirePackage{booktabs}
\RequirePackage{colortbl}
\RequirePackage{upgreek,latexsym,wasysym}
\RequirePackage{circuitikz}

\providecommand{\purpleddag}{\color{purple}{\ddag}}
\providecommand{\burntorangeddag}{\color{burntorange}{\ddag}}
\providecommand{\navyblueddag}{\color{navyblue}{\ddag}}
\providecommand{\redorangeddag}{\color{redorange}{\ddag}}
\providecommand{\pinegreenddag}{\color{forestgreen}{\ddag}}
\providecommand{\maroonddag}{\color{maroon}{\ddag}}

\RequirePackage[perpage,para,symbol*]{footmisc}
\DefineFNsymbols*{cfiandra}{\purpleddag\burntorangeddag\navyblueddag\maroonddag\pinegreenddag\redorangeddag\dagger *\S\P\|%
          {**}{\dagger\dagger}{\ddagger\ddagger}}
\setfnsymbol{cfiandra}

\RequirePackage[english]{babel}
\RequirePackage{engtlc}
\RequirePackage{fiandracolors}
\RequirePackage[pdfauthor={Fiandrino Claudio},pdfpagelabels,plainpages=false,colorlinks=true,hyperindex=true]{hyperref}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\def\ateneo#1{\gdef\@nomeateneo{#1}}
\def\corso#1{\gdef\@nomecorso{#1}}
\def\titolo#1{\gdef\@title{#1}}

\def\nome#1{\gdef\@nome{#1}}
\def\nomea#1{\gdef\@nomea{#1}}
\def\nomeb#1{\gdef\@nomeb{#1}}
\def\nomec#1{\gdef\@nomec{#1}}
\def\nomed#1{\gdef\@nomed{#1}}

\def\cognome#1{\gdef\@cognome{#1}}
\def\cognomea#1{\gdef\@cognomea{#1}}
\def\cognomeb#1{\gdef\@cognomeb{#1}}
\def\cognomec#1{\gdef\@cognomec{#1}}
\def\cognomed#1{\gdef\@cognomed{#1}}

\def\matricola#1{\gdef\@matricola{#1}}
\def\matricolaa#1{\gdef\@matricolaa{#1}}
\def\matricolab#1{\gdef\@matricolab{#1}}
\def\matricolac#1{\gdef\@matricolac{#1}}
\def\matricolad#1{\gdef\@matricolad{#1}}


\def\gruppo#1{\gdef\@gruppo{#1}}
\def\data#1{\gdef\@date{#1}}


\def\logo#1{\edef\@logo{\noexpand\includegraphics[keepaspectratio,width=3cm]{#1}}}

\def\frontespizio{
\pagestyle{empty}
\advance\oddsidemargin \evensidemargin
	      \divide\oddsidemargin \tw@
	      \evensidemargin \oddsidemargin
{\vspace*{-3\topskip}\centering \expandafter{\LARGE \@nomeateneo}\par}\vfill
{\centering \@logo\par}\vfill
{\centering \bf\huge \@nomecorso\par}\vfill
{\centering \bf\LARGE \@title\par}\vfill
{\centering \Large Gruppo: \@gruppo \par}\vfill
{\centering \Large
\@cognomea\; \@nomea \quad\quad Matricola:\, \@matricolaa\\
\@cognomeb\; \@nomeb \quad\quad Matricola:\, \@matricolab\\
\@cognomec\; \@nomec \quad\quad Matricola:\, \@matricolac\\
\@cognomed\; \@nomed \quad\quad Matricola:\, \@matricolad\\
}\vfill
\vfill\par\newpage
}
\def\frontespiziosingolo{
\pagestyle{empty}
\advance\oddsidemargin \evensidemargin
	      \divide\oddsidemargin \tw@
	      \evensidemargin \oddsidemargin
{\vspace*{-3\topskip}\centering \expandafter{\Large \@nomeateneo}\par}\vfill
{\centering \@logo\par}\vfill
{\centering \bf\huge \@nomecorso\par}\vfill
{\centering \bf\LARGE \@title\par}\vfill
{\centering \Large \@cognome\; \@nome \quad\quad Matricola:\, \@matricola\\
}\vfill
\vfill\par\newpage
}

\def\frontespiziosingolocondata{
\pagestyle{empty}
\advance\oddsidemargin \evensidemargin
	      \divide\oddsidemargin \tw@
	      \evensidemargin \oddsidemargin
{\vspace*{-3\topskip}\centering \expandafter{\Large \@nomeateneo}\par}\vfill
{\centering \@logo\par}\vfill
{\centering \bf\huge \@nomecorso\par}\vfill
{\centering \bf\LARGE \@title \par}\vfill
{\centering \Large \@cognome\; \@nome \quad\quad Matricola:\, \@matricola\\
}\vfill
{\centering \large \@date\par}\vfill
\vfill\par\newpage
}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Corpo del testo
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\def\corpotesto{
\pagestyle{fancy}
\fancyhead{}
\fancyhead[C]{\it\@title \,-\, \normalfont\if !\@date! \empty \today \else \@date \fi}
}

\def\corpotestofirst{
\pagestyle{fancy}
\fancyhead{}
\fancyhead[C]{\@title \, \if !\@date! \empty \today \else \@date \fi}
}

\def\corpotestosecond{
\pagestyle{fancy}
\fancyhead{}
\fancyhead[C]{\@title\, -\, \it \@cognome\,\@nome}
}


\endinput
